package com.hw.dms.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.hw.common.log.annotation.Log;
import com.hw.common.log.enums.BusinessType;
import com.hw.common.security.annotation.RequiresPermissions;
import com.hw.dms.domain.DmsBaseDeviceLedger;
import com.hw.dms.service.IDmsBaseDeviceLedgerService;
import com.hw.common.core.web.controller.BaseController;
import com.hw.common.core.web.domain.AjaxResult;
import com.hw.common.core.utils.poi.ExcelUtil;
import com.hw.common.core.web.page.TableDataInfo;

/**
 * 设备台账信息Controller
 *
 * @author xins
 * @date 2023-12-28
 */
@RestController
@RequestMapping("/ledger")
public class DmsBaseDeviceLedgerController extends BaseController
{
    @Autowired
    private IDmsBaseDeviceLedgerService dmsBaseDeviceLedgerService;

    /**
     * 查询设备台账信息列表
     */
    @RequiresPermissions("dms:ledger:list")
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseDeviceLedger dmsBaseDeviceLedger)
    {
        startPage();
        List<DmsBaseDeviceLedger> list = dmsBaseDeviceLedgerService.selectDmsBaseDeviceLedgerList(dmsBaseDeviceLedger);
        return getDataTable(list);
    }

    /**
     * 导出设备台账信息列表
     */
    @RequiresPermissions("dms:ledger:export")
    @Log(title = "设备台账信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseDeviceLedger dmsBaseDeviceLedger)
    {
        List<DmsBaseDeviceLedger> list = dmsBaseDeviceLedgerService.selectDmsBaseDeviceLedgerList(dmsBaseDeviceLedger);
        ExcelUtil<DmsBaseDeviceLedger> util = new ExcelUtil<DmsBaseDeviceLedger>(DmsBaseDeviceLedger.class);
        util.exportExcel(response, list, "设备台账信息数据");
    }

    /**
     * 获取设备台账信息详细信息
     */
    @RequiresPermissions("dms:ledger:query")
    @GetMapping(value = "/{deviceId}")
    public AjaxResult getInfo(@PathVariable("deviceId") Long deviceId)
    {
        return success(dmsBaseDeviceLedgerService.selectDmsBaseDeviceLedgerByDeviceId(deviceId));
    }

    /**
     * 新增设备台账信息
     */
    @RequiresPermissions("dms:ledger:add")
    @Log(title = "设备台账信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseDeviceLedger dmsBaseDeviceLedger)
    {
        return toAjax(dmsBaseDeviceLedgerService.insertDmsBaseDeviceLedger(dmsBaseDeviceLedger));
    }

    /**
     * 修改设备台账信息
     */
    @RequiresPermissions("dms:ledger:edit")
    @Log(title = "设备台账信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseDeviceLedger dmsBaseDeviceLedger)
    {
        return toAjax(dmsBaseDeviceLedgerService.updateDmsBaseDeviceLedger(dmsBaseDeviceLedger));
    }

    /**
     * 删除设备台账信息
     */
    @RequiresPermissions("dms:ledger:remove")
    @Log(title = "设备台账信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deviceIds}")
    public AjaxResult remove(@PathVariable Long[] deviceIds)
    {
        return toAjax(dmsBaseDeviceLedgerService.deleteDmsBaseDeviceLedgerByDeviceIds(deviceIds));
    }
}
